@@ -37,7 +37,7 @@ class stat_entry(models.Model):
     value = models.FloatField(null=True, blank=True, default=0.0)
     time_stamp = models.DateTimeField(auto_now_add=True)
 
-    class META:
+    class Meta:
         get_latest_by = 'time_stamp'
 
     def __unicode__(self):
