@@ -23,7 +23,7 @@ class display_client_detail(DetailView):
             client_stat_entries = models.stat_entry.objects.filter(
                 host=client,
                 type=stat_type,
-            )
+            ).latest()
 
             for client_stat_entry in client_stat_entries:
                 disk_name = client_stat_entry.disk
